@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-#   Copyright (C) 2008-2009, 2013-2017, 2019-2021, 2023-2024 Rocky
+#   Copyright (C) 2008-2009, 2013-2017, 2019-2021, 2023-2025 Rocky
 #   Bernstein <rocky@gnu.org>
 #
 #   This program is free software: you can redistribute it and/or modify
@@ -34,104 +34,20 @@ if necessary, first.
 # functions below.  It also doesn't work once we add the exception handling
 # we see below. So for now, we'll live with the code duplication.
 
+import os
 import sys
-from typing import Callable, Optional
+import traceback
 
 from trepan.debugger import Trepan, debugger_obj
+from trepan.interfaces.server import ServerInterface
+from trepan.lib.default import DEBUGGER_SETTINGS
 from trepan.post_mortem import post_mortem_excepthook, uncaught_exception
 
-
-def debugger_on_post_mortem():
-    """Call debugger on an exception that terminates a program"""
-    sys.excepthook = post_mortem_excepthook
-    return
-
-
-def run_eval(
-    expression,
-    debug_opts: Optional[dict] = None,
-    start_opts: Optional[dict] = None,
-    globals_: Optional[dict] = None,
-    locals_: Optional[dict] = None,
-    tb_fn: Optional[Callable] = None,
-):
-    """Evaluate the expression (given as a string) under debugger
-    control starting with the statement after the place that
-    this appears in your program.
-
-    This is a wrapper to Debugger.run_eval(), so see that.
-
-    When run_eval() returns, it returns the value of the expression.
-    Otherwise, this function is similar to run().
-    """
-
-    dbg = Trepan(opts=debug_opts)
-    try:
-        return dbg.run_eval(
-            expression, start_opts=start_opts, globals_=globals_, locals_=locals_
-        )
-    except Exception:
-        dbg.core.trace_hook_suspend = True
-        if start_opts and "tb_fn" in start_opts:
-            tb_fn = start_opts["tb_fn"]
-        uncaught_exception(dbg, tb_fn)
-    finally:
-        dbg.core.trace_hook_suspend = False
-    return
-
-
-def run_call(
-    func: Callable,
-    *args,
-    debug_opts: Optional[dict] = None,
-    start_opts: Optional[dict] = None,
-    **kwds,
-):
-    """Call the function (a function or method object, not a string)
-    with the given arguments starting with the statement after
-    the place that this appears in your program.
-
-    When run_call() returns, it returns whatever the function call
-    returned.  The debugger prompt appears as soon as the function is
-    entered."""
-
-    dbg = Trepan(opts=debug_opts)
-    try:
-        return dbg.run_call(func, *args, **kwds)
-    except Exception:
-        uncaught_exception(dbg)
-        pass
-    return
-
-
-def run_exec(statement, debug_opts=None, start_opts=None, globals_=None, locals_=None):
-    """Execute the statement (given as a string) under debugger
-    control starting with the statement subsequent to the place that
-    this run_call appears in your program.
-
-    This is a wrapper to Debugger.run_exec(), so see that.
-
-    The debugger prompt appears before any code is executed;
-    you can set breakpoints and type 'continue', or you can step
-    through the statement using 'step' or 'next'
-
-    The optional globals_ and locals_ arguments specify the environment
-    in which the code is executed; by default the dictionary of the
-    module __main__ is used."""
-
-    dbg = Trepan(opts=debug_opts)
-    try:
-        return dbg.run_exec(
-            statement, start_opts=start_opts, globals_=globals_, locals_=locals_
-        )
-    except Exception:
-        uncaught_exception(dbg)
-        pass
-    return
+DEFAULT_DEBUG_PORT = 1955
 
 
 def debug(
-    dbg_opts=None,
+    dbg_opts={},
     start_opts=None,
     post_mortem: bool = True,
     step_ignore: int = 1,
@@ -257,6 +173,7 @@ def debug(
         core.processor.queue_startfile(init_cmdfile)
 
     if not core.is_started():
+        core.add_ignore(debug, stop)
         core.start(start_opts)
         pass
     if post_mortem:
@@ -275,6 +192,101 @@ def debug(
     return
 
 
+def debug_for_remote_access():
+    """Enter the debugger in a mode that allows connection to it
+    outside of the process being debugged.
+    """
+    connection_opts = {
+        "IO": "TCP",
+        "PORT": os.getenv("TREPAN3K_TCP_PORT", DEFAULT_DEBUG_PORT),
+    }
+    intf = ServerInterface(connection_opts=connection_opts)
+    dbg_opts = {'interface': intf}
+    print('Starting %s server listening on %s.' % (connection_opts["IO"], connection_opts["PORT"]),
+          file=sys.stderr)
+    print('Use `python3 -m trepan.client --port %s to enter the debugger.' % connection_opts["PORT"],
+          file=sys.stderr)
+    debug(dbg_opts=dbg_opts, step_ignore=0, level=1)
+
+def debugger_on_post_mortem():
+    """Call debugger on an exception that terminates a program"""
+    sys.excepthook = post_mortem_excepthook
+    return
+
+
+def run_call(func, *args, debug_opts=DEBUGGER_SETTINGS, start_opts=None, **kwds):
+    """Call the function (a function or method object, not a string)
+    with the given arguments starting with the statement after
+    the place that this appears in your program.
+
+    When run_call() returns, it returns whatever the function call
+    returned.  The debugger prompt appears as soon as the function is
+    entered."""
+
+    dbg = Trepan(opts=debug_opts)
+    try:
+        return dbg.run_call(func, *args, **kwds)
+    except Exception:
+        uncaught_exception(dbg)
+        pass
+    return
+
+
+def run_eval(expression, debug_opts = DEBUGGER_SETTINGS, start_opts = None, globals_ = None, locals_ = None, _ = None):
+    """Evaluate the expression (given as a string) under debugger
+    control starting with the statement after the place that
+    this appears in your program.
+
+    This is a wrapper to Debugger.run_eval(), so see that.
+
+    When run_eval() returns, it returns the value of the expression.
+    Otherwise, this function is similar to run().
+    """
+
+    dbg = Trepan(opts=debug_opts)
+    try:
+        return dbg.run_eval(
+            expression, start_opts=start_opts, globals_=globals_, locals_=locals_
+        )
+    except Exception:
+        dbg.core.trace_hook_suspend = True
+        traceback.print_exc()
+    finally:
+        dbg.core.trace_hook_suspend = False
+    return
+
+
+def run_exec(
+    statement,
+    debug_opts = DEBUGGER_SETTINGS,
+    start_opts=None,
+    globals_=None,
+    locals_=None,
+):
+    """Execute the statement (given as a string) under debugger
+    control starting with the statement subsequent to the place that
+    this run_call appears in your program.
+
+    This is a wrapper to Debugger.run_exec(), so see that.
+
+    The debugger prompt appears before any code is executed;
+    you can set breakpoints and type 'continue', or you can step
+    through the statement using 'step' or 'next'
+
+    The optional globals_ and locals_ arguments specify the environment
+    in which the code is executed; by default the dictionary of the
+    module __main__ is used."""
+
+    dbg = Trepan(opts=debug_opts)
+    try:
+        return dbg.run_exec(
+            statement, start_opts=start_opts, globals_=globals_, locals_=locals_
+        )
+    except Exception:
+        uncaught_exception(dbg)
+        pass
+    return
+
 def stop(opts=None):
     if isinstance(debugger_obj, Trepan):
         return debugger_obj.stop(opts)
@@ -316,10 +328,12 @@ if __name__ == "__main__":
     }
     if len(sys.argv) > 1:
         print(
-            f"Issuing interactive: run_call(plus5, {int(sys.argv[1])}, debug_opts={debug_opts})"
+            "Issuing interactive: run_call(plus5, %s)" % sys.argv[1]
         )
         run_call(plus5, int(sys.argv[1]), debug_opts=debug_opts)
     else:
-        print(f"Issuing interactive: run_call(plus5, 2, debug_opts={debug_opts})")
+        print(
+            "Issuing interactive: run_call(plus5, 2)"
+        )
         run_call(plus5, 2, debug_opts=debug_opts)
     pass
