@@ -14,10 +14,11 @@
 #  You should have received a copy of the GNU General Public License
 #  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+from trepan.lib.stack import frame2file
 from trepan.processor.location import resolve_location
 from trepan.processor.parse.parser import LocationError
 from trepan.processor.parse.scanner import ScannerError
-from trepan.processor.parse.semantics import Location, build_location, build_range
+from trepan.processor.parse.semantics import Location, RangeError, build_location, build_range
 
 INVALID_PARSE_LIST = (None, None, None)
 
@@ -63,6 +64,9 @@ def parse_list_cmd(proc, args, listsize=10):
             proc.errmsg(e.text)
             proc.errmsg(e.text_cursor)
             return INVALID_PARSE_LIST
+        except RangeError as e:
+            proc.errmsg(e.errmsg)
+            return INVALID_PARSE_LIST
 
         if list_range.first is None:
             # Last must have been given
@@ -87,10 +91,20 @@ def parse_list_cmd(proc, args, listsize=10):
         else:
             # First is location. Last may be empty or a number
             assert isinstance(list_range.first, Location)
-            location = resolve_location(proc, list_range.first)
-            if not location:
-                return INVALID_PARSE_LIST
-            first = location.line_number
+            first = list_range.first.line_number
+            if list_range.first.path is None:
+                if list_range.first.method is None:
+                    filename = frame2file(proc.core, proc.curframe, canonic=False)
+                else:
+                    location = resolve_location(proc, list_range.first)
+                    if location is None or location == INVALID_PARSE_LOCATION:
+                        return INVALID_PARSE_LIST
+                    filename = location.path
+                    if first is None:
+                        first = location.line_number
+            else:
+                filename = list_range.first.path
+
             last = list_range.last
             # if location.method:
             #     first -= listsize // 2
@@ -100,11 +114,13 @@ def parse_list_cmd(proc, args, listsize=10):
                 last = first + int(last[1:])
             elif not last:
                 last = first + listsize
+            elif first is None:
+                return INVALID_PARSE_LIST
             elif last < first:
                 # Treat as a count rather than an absolute location
                 last = first + last
 
-            return location.path, first, last
+            return filename, first, last
         pass
     return
 
