@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-#  Copyright (C) 2009, 2013, 2015, 2017, 2020 Rocky Bernstein
+#  Copyright (C) 2009, 2013, 2015, 2017, 2020, 2024-2025 Rocky Bernstein
 #
 #  This program is free software: you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -14,8 +14,8 @@
 #  You should have received a copy of the GNU General Public License
 #  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from trepan.processor.command.base_cmd import DebuggerCommand
 from trepan.processor.cmdbreak import parse_break_cmd, set_break
+from trepan.processor.command.base_cmd import DebuggerCommand
 
 
 class ContinueCommand(DebuggerCommand):
@@ -52,11 +52,18 @@ class ContinueCommand(DebuggerCommand):
         if len(args) > 1:
             # FIXME: DRY this code. Better is to hook into tbreak.
             func, filename, lineno, condition, offset = parse_break_cmd(self.proc, args)
-            if not set_break(self, func, filename, lineno, condition, True, args):
-                return False
+            if not (func is None and filename is None):
+                set_break(
+                    self, func, filename, lineno, condition, True, args, offset=offset
+                    )
+            else:
+                self.errmsg(f"Did not find stopping spot for: {' '.join(args[1:])}")
         self.core.step_events = None  # All events
         self.core.step_ignore = -1
         self.proc.continue_running = True  # Break out of command read loop
+
+        # Try to remove debugger hook if no breakpoints are set.
+        self.proc.fast_continue = True
         return True
 
     pass
@@ -64,29 +71,34 @@ class ContinueCommand(DebuggerCommand):
 
 if __name__ == "__main__":
     import sys
+
+    def five():
+        return 5
+
     from trepan.debugger import Trepan
 
     d = Trepan()
     cmd = ContinueCommand(d.core.processor)
     cmd.proc.frame = sys._getframe()
+    line = cmd.proc.frame.f_lineno
+    # Leave this line after line_str blank!
     cmd.proc.setup()
 
     for c in (
         ["continue", "wrong", "number", "of", "args"],
-        ["c", "5"],
-        ["continue", "1+2"],
-        ["c", "foo"],
+        ["c", str(line)],
+        ["c", str(line + 1)],  # Invalid
+        ["continue", "1"],
+        ["c", "five"],
+        ["c", "five()"],
     ):
         d.core.step_ignore = 0
         cmd.continue_running = False
+        cmd.proc.current_command = " ".join(c)
         result = cmd.run(c)
-        print("Run result: %s" % result)
+        print(f"Run result: {result}")
         print(
-            "step_ignore %d, continue_running: %s"
-            % (
-                d.core.step_ignore,
-                cmd.continue_running,
-            )
+            f"step_ignore {d.core.step_ignore}, continue_running: {cmd.continue_running}"
         )
         pass
     pass
