@@ -90,7 +90,7 @@ class DisassembleCommand(DebuggerCommand):
     disassemble that.
 
     Assembly output format is be controlled by the setting of `set
-    asmfmt`. Output formats are those described the `xdis` `pydisasm`
+    disasmflavor`. Output formats are those described the `xdis` `pydisasm`
     disassembler.
 
 
@@ -110,7 +110,7 @@ class DisassembleCommand(DebuggerCommand):
     See also:
     ---------
 
-    `help syntax arange`, `deparse`, `list`, `info pc`, `set asmfmt`.
+    `help syntax arange`, `deparse`, `list`, `info pc`, `set disasmflavor`.
 
     """
 
@@ -126,13 +126,13 @@ class DisassembleCommand(DebuggerCommand):
         listsize = 4
 
         opts = {
-            "highlight": self.settings["highlight"],
+            "style": self.settings["style"],
             "start_line": 1,
             "end_line": None,
             "start_offset": None,
             "end_offset": None,
             "relative_pos": False,
-            "asm_format": self.settings["asmfmt"],
+            "asm_format": self.settings["disasmflavor"],
         }
 
         curframe = proc.curframe
@@ -184,10 +184,12 @@ class DisassembleCommand(DebuggerCommand):
             opts["start_offset"] = start
         else:
             opts["start_line"] = start
+            opts["start_offset"] = 0
         if last_is_offset:
             opts["end_offset"] = last
         else:
             opts["end_line"] = last
+            opts["end_offset"] = None
 
         if not obj and (
             bytecode_file
